@@ -114,7 +114,7 @@ class ImageRecognition(object):
         with slim.arg_scope(arg_scope):
             # get output (logits)
             out, end_points = inception_v4(input_tensor, 
-                                           num_classes=1001, 
+                                           num_classes=100, 
                                            final_endpoint=final_endpoint, 
                                            is_training=is_training)
             # get inception variable name
@@ -146,7 +146,7 @@ class ImageRecognition(object):
                                 num_inputs = depth, 
                                 num_outputs = len(self.classes), 
                                 name = 'fc1', 
-                                dropout_val=0.85, 
+                                dropout_val=1, 
                                 activation="NONE",
                                 lrelu_alpha=0.2, 
                                 data_type=tf.float32,
